# MIT License

# Copyright (c) 2024 Yuan-Man

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from transformers import pipeline

def whisper(speech_file_path, model_name="openai/whisper-small"):
    """
    This function utilizes the Whisper model for automatic speech recognition (ASR) on a given audio file.
    
    Parameters:
    speech_file_path (str): The path to the audio file for transcription.
    model_name (str): The name of the Whisper model used for ASR. Default is "openai/whisper-small".
    
    Returns:
    str: The transcribed text from the audio file.
    """
    # Create an ASR pipeline using the specified model
    asr_pipeline = pipeline("automatic-speech-recognition", model=model_name)

    # Use the Whisper model for speech recognition on the audio file
    transcript = asr_pipeline(speech_file_path)

    # Return the transcribed text
    return transcript
